==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebPageCancellableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPageCancellableEventArgsDetailDescriptionMetadata } from "./WebPageCancellableEventArgsDetailDescriptionMetadata";
import { WebPageCancellableEventArgsDescription } from "./WebPageCancellableEventArgsDescription";
/**
 * @hidden
 */
var WebPageCancellableEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPageCancellableEventArgsDescriptionMetadata, _super);
    function WebPageCancellableEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPageCancellableEventArgsDescriptionMetadata.b = function (a) {
        if (WebPageCancellableEventArgsDescriptionMetadata.a == null) {
            WebPageCancellableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPageCancellableEventArgsDescriptionMetadata.c(WebPageCancellableEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebPageCancellableEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPageCancellableEventArgsDescriptionMetadata.a);
        WebPageCancellableEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPageCancellableEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PageCancellableEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebPageCancellableEventArgsDetail");
    };
    WebPageCancellableEventArgsDescriptionMetadata.d = function (a) {
        WebPageCancellableEventArgsDescriptionMetadata.b(a);
        a.aa("WebPageCancellableEventArgs", function () { return new WebPageCancellableEventArgsDescription(); });
        a.z("WebPageCancellableEventArgs", WebPageCancellableEventArgsDescriptionMetadata.a);
    };
    WebPageCancellableEventArgsDescriptionMetadata.$t = markType(WebPageCancellableEventArgsDescriptionMetadata, 'WebPageCancellableEventArgsDescriptionMetadata');
    WebPageCancellableEventArgsDescriptionMetadata.a = null;
    return WebPageCancellableEventArgsDescriptionMetadata;
}(Base));
export { WebPageCancellableEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebPageCancellableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPageCancellableEventArgsDetailDescriptionMetadata } from "./WebPageCancellableEventArgsDetailDescriptionMetadata";
import { WebPageCancellableEventArgsDescription } from "./WebPageCancellableEventArgsDescription";
/**
 * @hidden
 */
var WebPageCancellableEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPageCancellableEventArgsDescriptionMetadata, _super);
    function WebPageCancellableEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPageCancellableEventArgsDescriptionMetadata.b = function (a) {
        if (WebPageCancellableEventArgsDescriptionMetadata.a == null) {
            WebPageCancellableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPageCancellableEventArgsDescriptionMetadata.c(WebPageCancellableEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPageCancellableEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPageCancellableEventArgsDescriptionMetadata.a);
        WebPageCancellableEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPageCancellableEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PageCancellableEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebPageCancellableEventArgsDetail");
    };
    WebPageCancellableEventArgsDescriptionMetadata.d = function (a) {
        WebPageCancellableEventArgsDescriptionMetadata.b(a);
        a.ac("WebPageCancellableEventArgs", function () { return new WebPageCancellableEventArgsDescription(); });
        a.ab("WebPageCancellableEventArgs", WebPageCancellableEventArgsDescriptionMetadata.a);
    };
    WebPageCancellableEventArgsDescriptionMetadata.$t = markType(WebPageCancellableEventArgsDescriptionMetadata, 'WebPageCancellableEventArgsDescriptionMetadata');
    WebPageCancellableEventArgsDescriptionMetadata.a = null;
    return WebPageCancellableEventArgsDescriptionMetadata;
}(Base));
export { WebPageCancellableEventArgsDescriptionMetadata };
